/******************************************************************************
 ParseVerb.sc
 Contains logic for calling procedures based on Said() parses.  Matches
 very closely to the grammar portion in the reform file
 ******************************************************************************/
(include "sci.sh")
(include "game.sh")
/******************************************************************************/
(script PARSEVERB_SCRIPT)
(use "main")
/******************************************************************************/
(procedure public (ParseVerb) 
  // Initialize verb to nothing
    = Verb UNSET
    = needNoun FALSE
    = needSecond FALSE
    = unneededNoun FALSE
    = unneededSecond FALSE

    /* Minimum
         Verb/Noun/Second
         Verb/Noun
         Verb
    */

    /********** CUT **********/
    (if(Said('(cut,saw)/*/*>')) 
       = Verb VERB_CUT    
	)

    (if(Said('(cut,saw)/*[/!*]>'))
       = Verb VERB_CUT
       = needSecond TRUE     // what do you want to cut the <noun> with
	)

    (if(Said('(cut,saw)[/!*]>'))
       = Verb VERB_CUT
       = needNoun TRUE       // what do you want to cut?	
	)
	
	/********** CLIMB UP **********/
	(if(Said('climb[<up]/*/*>'))
	   = Verb VERB_CLIMBUP
	   = unneededSecond TRUE
	)

	(if(Said('climb[<up]/*[/!*]>'))   // if just 'climb', infer 'climb up'
       = Verb VERB_CLIMBUP	
	)
	
	(if(Said('climb[<up][/!*]>'))
	   = Verb VERB_CLIMBUP
	   = needNoun TRUE	        // what do you want to climb?
	)
	
	/********** CLIMB DOWN **********/
    (if(Said('(climb,descend)<down/*/*>')) 
       = Verb VERB_CLIMBDOWN	
       = unneededSecond TRUE
	)
	
    (if(Said('(climb,descend)<down/*[/!*]>')) 
       = Verb VERB_CLIMBDOWN	
	)
    
	(if(Said('(climb,descend)<down[/!*]>'))  // infer what we are climbing down - we do not need a noun
       = Verb VERB_CLIMBDOWN   
	)
	
	
	/********** DIG **********/
	(if(Said('dig/*/*>'))
	   = Verb VERB_DIG	
	)
	
	(if(Said('dig/*[/!*]>'))
	   = Verb VERB_DIG
	   = needSecond TRUE	
	)
	
	(if(Said('dig[/!*]>'))  // technically do not need 'no claim' operator here.  should just stop processing
	   = Verb VERB_DIG
	   = needNoun TRUE      // what do you want to dig in?
	)

	
	/********** LISTEN **********/
	(if(Said('listen/*/*>'))
	   = Verb VERB_LISTEN
	   = unneededSecond TRUE	
	)
 
    (if(Said('listen<*/[/*]>'))
       = Verb VERB_LISTEN
       = needNoun TRUE
    )
	
	(if(Said('listen/*[/!*]>')) 
	   = Verb VERB_LISTEN	
	)
	
	(if(Said('listen[/!*]>'))
	   = Verb VERB_LISTEN	
	)
	
	/********** EXAMINE **********/
	(if(Said('(examine,look)/*/*>'))  // examine tree with <magnifying glass> -- bad parse for this game
	   = Verb VERB_LOOK
	   = unneededSecond TRUE
	)   	
 
    (if(Said('(examine,look)<*/[/*]>'))
       = Verb VERB_LOOK
       = needNoun TRUE
    )
	
	(if(Said('(examine,look)/*[/*]>'))
	   = Verb VERB_LOOK
	)   
	
	(if(Said('(examine,look)[/*]>'))
	   = Verb VERB_LOOK
	)   
	 
	/********** RUN **********/
	(if(Said('run/*/*>'))
	   = Verb VERB_RUN
	   = unneededNoun TRUE
	   = unneededSecond TRUE // superfluous, since we will error with 'uneededNoun'	
	)
 
    (if(Said('run<*/[/*]>'))
       = Verb VERB_RUN
       = needNoun TRUE
    )
	
    (if(Said('run/*[/!*]>')) 
       = Verb VERB_RUN	
       = unneededNoun TRUE   // you can only 'run'
	)
	
	(if(Said('run[/!*]>'))
	   = Verb VERB_RUN
	)
	
)
/******************************************************************************/
